@@ -2,13 +2,14 @@
 """
 Logical permission backends module
 """
-__author__ = 'Alisue <lambdalisue@hashnote.net>'
-__all__ = ('PermissionBackend',)
 from permission.conf import settings
 from permission.utils.handlers import registry
 from permission.utils.permissions import perm_to_permission
 
 
+__all__    = ('PermissionBackend',)
+
+
 class PermissionBackend(object):
     """
     A handler based permission backend
@@ -17,6 +18,7 @@ class PermissionBackend(object):
     supports_anonymous_user = True
     supports_inactive_user = True
 
+    # pylint:disable=unused-argument
     def authenticate(self, username, password):
         """
         Always return ``None`` to prevent authentication within this backend.
@@ -44,7 +46,7 @@ class PermissionBackend(object):
         Returns
         -------
         boolean
-            Wheter the specified user have specified permission (of specified
+            Whether the specified user have specified permission (of specified
             object).
 
         Raises
@@ -57,7 +59,11 @@ class PermissionBackend(object):
         if settings.PERMISSION_CHECK_PERMISSION_PRESENCE:
             # get permission instance from string permission (perm)
             # it raise ObjectDoesNotExists when the permission is not exists
-            perm_to_permission(perm)
+            try:
+                perm_to_permission(perm)
+            except AttributeError:
+                # Django 1.2 internally use wrong permission string thus ignore
+                pass
 
         # get permission handlers fot this perm
         cache_name = '_%s_cache' % perm
@@ -85,17 +91,14 @@ class PermissionBackend(object):
         Parameters
         ----------
         user_obj : django user model instance
-            A django user model instance which be checked
-        perm : string
+            A django user model instance which is checked
+        app_label : string
             `app_label.codename` formatted permission string
-        obj : None or django model instance
-            None or django model instance for object permission
 
         Returns
         -------
         boolean
-            Wheter the specified user have specified permission (of specified
-            object).
+            Whether the specified user have specified permission.
 
         Raises
         ------
