@@ -2,14 +2,17 @@
 """
 django-permission application configure
 """
-__author__ = 'Alisue <lambdalisue@hashnote.net>'
-__all__ = ('settings',)
 from django.conf import settings
+from django.core.exceptions import ImproperlyConfigured
 from appconf import AppConf
 from permission.handlers import LogicalPermissionHandler
 
+
+__all__ = ('settings',)
+
+
 class PermissionConf(AppConf):
-    DEFAULT_PERMISSION_HANDLER = LogicalPermissionHandler
+    DEFAULT_PERMISSION_HANDLER = 'permission.handlers.LogicalPermissionHandler'
     """Default permission handler class"""
 
     CHECK_PERMISSION_PRESENCE = settings.DEBUG
@@ -44,3 +47,10 @@ class PermissionConf(AppConf):
 
     AUTODISCOVER_MODULE_NAME = 'perms'
     AUTODISCOVER_VARIABLE_NAME = 'PERMISSION_LOGICS'
+    AUTODISCOVER_ENABLE = True
+
+    CHECK_AUTHENTICATION_BACKENDS = True
+    """Check if AUTHENTICATION_BACKENDS is correctly configured"""
+
+    CHECK_TEMPLATES_OPTIONS_BUILTINS = True
+    """Check if TEMPLATES[?]['OPTIONS']['builtins'] is correctly configured"""
