@@ -1,10 +1,7 @@
 # coding=utf-8
-"""
-"""
-__author__ = 'Alisue <lambdalisue@hashnote.net>'
+import collections
 from permission.utils.permissions import get_app_perms
 from permission.utils.permissions import get_model_perms
-import collections
 
 
 class PermissionHandler(object):
@@ -147,7 +144,7 @@ class PermissionHandler(object):
         Returns
         -------
         boolean
-            Wheter the specified user have specified permission (of specified
+            Whether the specified user have specified permission (of specified
             object).
 
         .. note::
@@ -172,7 +169,7 @@ class PermissionHandler(object):
         Returns
         -------
         boolean
-            Wheter the specified user have any permissions of specified app
+            Whether the specified user have any permissions of specified app
 
         """
         cache_name = "_has_module_perms_%s_%s_cache" % (app_label, user_obj.pk)
@@ -233,7 +230,7 @@ class LogicalPermissionHandler(PermissionHandler):
         Returns
         -------
         boolean
-            Wheter the specified user have specified permission (of specified
+            Whether the specified user have specified permission (of specified
             object).
         """
         if perm not in self.get_supported_permissions():
@@ -252,7 +249,7 @@ class LogicalPermissionHandler(PermissionHandler):
         if perm not in self.get_supported_permissions():
             return False
         for permission_logic in getattr(self.model,
-                                        '_permission_logics', []):
+                                        '_permission_logics', set()):
             if permission_logic.has_perm(user_obj, perm, obj):
                 return True
         return False
