@@ -2,10 +2,10 @@
 """
 Permission logic module for collaborators based permission system
 """
-__author__ = 'Alisue <lambdalisue@hashnote.net>'
 from permission.conf import settings
 from permission.logics.base import PermissionLogic
 from permission.utils.field_lookup import field_lookup
+from permission.compat import is_authenticated
 
 
 class CollaboratorsPermissionLogic(PermissionLogic):
@@ -101,10 +101,10 @@ class CollaboratorsPermissionLogic(PermissionLogic):
         Returns
         -------
         boolean
-            Wheter the specified user have specified permission (of specified
+            Whether the specified user have specified permission (of specified
             object).
         """
-        if not user_obj.is_authenticated():
+        if not is_authenticated(user_obj):
             return False
         # construct the permission full name
         change_permission = self.get_full_permission_string('change')
