@@ -2,9 +2,9 @@
 """
 Permission logic module for group based permission system
 """
-__author__ = 'Alisue <lambdalisue@hashnote.net>'
 from permission.conf import settings
 from permission.logics.base import PermissionLogic
+from permission.compat import is_authenticated
 
 
 class GroupInPermissionLogic(PermissionLogic):
@@ -16,7 +16,7 @@ class GroupInPermissionLogic(PermissionLogic):
                  any_permission=None,
                  add_permission=None,
                  change_permission=None,
-                 delete_permission=None):
+                 delete_permission=None):   # noqa
         """
         Constructor
 
@@ -87,7 +87,7 @@ class GroupInPermissionLogic(PermissionLogic):
         This permission logic is used mainly for group based role permission
         system.
         You can change this behavior to set ``any_permission``,
-        ``add_permission``, ``change_permissino``, or ``delete_permission``
+        ``add_permission``, ``change_permission``, or ``delete_permission``
         attributes of this instance.
 
         Parameters
@@ -102,10 +102,10 @@ class GroupInPermissionLogic(PermissionLogic):
         Returns
         -------
         boolean
-            Wheter the specified user have specified permission (of specified
+            Whether the specified user have specified permission (of specified
             object).
         """
-        if not user_obj.is_authenticated():
+        if not is_authenticated(user_obj):
             return False
         # construct the permission full name
         add_permission = self.get_full_permission_string('add')
