@@ -2,9 +2,9 @@
 """
 Permission logic module for author based permission system
 """
-__author__ = 'Alisue <lambdalisue@hashnote.net>'
 from permission.conf import settings
 from permission.logics.base import PermissionLogic
+from permission.compat import is_authenticated
 
 
 class StaffPermissionLogic(PermissionLogic):
@@ -98,7 +98,7 @@ class StaffPermissionLogic(PermissionLogic):
             Weather the specified user have specified permission (of specified
             object).
         """
-        if not user_obj.is_authenticated():
+        if not is_authenticated(user_obj):
             return False
         # construct the permission full name
         add_permission = self.get_full_permission_string('add')
