@@ -4,20 +4,16 @@ permissionif templatetag
 """
 from django import template
 from django.template import TemplateSyntaxError
-from django.template import VariableDoesNotExist
 from django.template.smartif import infix
 from django.template.smartif import IfParser
 from django.template.smartif import OPERATORS
-from django.template.defaulttags import Node
-from django.template.defaulttags import NodeList
+from django.template.defaulttags import IfNode
 from django.template.defaulttags import TemplateLiteral
-
 from permission.conf import settings
-from permission.templatetags.patch import IfNode
-from permission.templatetags.patch import parser_patch
 
 register = template.Library()
 
+
 def of_operator(context, x, y):
     """
     'of' operator of permission if
@@ -26,10 +22,11 @@ def of_operator(context, x, y):
     """
     return x.eval(context), y.eval(context)
 
+
 def has_operator(context, x, y):
     """
     'has' operator of permission if
-    
+
     This operator is used to specify the user object of permission
     """
     user = x.eval(context)
@@ -46,9 +43,10 @@ EXTRA_OPERATORS = {
     'has': infix(10, has_operator),
 }
 EXTRA_OPERATORS.update(OPERATORS)
-for key, op in list(EXTRA_OPERATORS.items()):
+for key, op in EXTRA_OPERATORS.items():
     op.id = key
 
+
 class PermissionIfParser(IfParser):
     """Permission if parser"""
     OPERATORS = EXTRA_OPERATORS
@@ -63,6 +61,7 @@ class PermissionIfParser(IfParser):
         else:
             return op()
 
+
 class TemplatePermissionIfParser(PermissionIfParser):
     error_class = TemplateSyntaxError
 
@@ -97,9 +96,6 @@ def do_permissionif(parser, token):
         {% endpermission %}
 
     """
-    # patch parser for django 1.3.1
-    parser = parser_patch(parser)
-
     bits = token.split_contents()
     ELIF = "el%s" % bits[0]
     ELSE = "else"
@@ -132,5 +128,17 @@ def do_permissionif(parser, token):
     return IfNode(conditions_nodelists)
 do_permissionif.Parser = TemplatePermissionIfParser
 
-if settings.PERMISSION_REPLACE_BUILTIN_IF:
-    register.tag('if', do_permissionif)
+
+# To replace builtin if
+def replace_builtin_if(replace=False):
+    if replace:
+        OPERATORS.update({
+            'has': EXTRA_OPERATORS['has'],
+            'of': EXTRA_OPERATORS['of'],
+        })
+    else:
+        # remove of, has from OPERATORS
+        OPERATORS.pop('of', None)
+        OPERATORS.pop('has', None)
+
+replace_builtin_if(settings.PERMISSION_REPLACE_BUILTIN_IF)
