@@ -1,29 +1,31 @@
-# coding=utf-8
-"""
-"""
-__author__ = 'Alisue <lambdalisue@hashnote.net>'
+from __future__ import unicode_literals
 from django.db import models
-from django.contrib.auth.models import User
+from django.conf import settings
+from django.utils.encoding import python_2_unicode_compatible
 
 
+AUTH_USER = getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
+
+
+@python_2_unicode_compatible
 class Article(models.Model):
     title = models.CharField('title', max_length=200)
     content = models.TextField('content')
 
     author = models.ForeignKey(
-        User, null=True,
+        AUTH_USER, null=True,
         related_name='permission_test_articles_author')
     editor = models.ForeignKey(
-        User, null=True,
+        AUTH_USER, null=True,
         related_name='permission_test_articles_editor')
     authors = models.ManyToManyField(
-        User, related_name='permission_test_articles_authors')
+        AUTH_USER, related_name='permission_test_articles_authors')
     editors = models.ManyToManyField(
-        User, related_name='permission_test_articles_editors')
+        AUTH_USER, related_name='permission_test_articles_editors')
 
     single_bridge = models.ForeignKey(
         'permission.Bridge', null=True,
-        related_name='permission_test_signgle_bridge')
+        related_name='permission_test_single_bridge')
     multiple_bridge = models.ManyToManyField(
         'permission.Bridge',
         related_name='permission_test_multiple_bridge')
@@ -33,15 +35,15 @@ class Article(models.Model):
     class Meta:
         app_label = 'permission'
 
-    def __unicode__(self):
+    def __str__(self):
         return self.title
 
 
 class Bridge(models.Model):
     author = models.ForeignKey(
-        User, null=True, related_name='permission_test_bridge_author')
+        AUTH_USER, null=True, related_name='permission_test_bridge_author')
     editors = models.ManyToManyField(
-        User, related_name='permission_test_bridge_editors')
+        AUTH_USER, related_name='permission_test_bridge_editors')
 
     class Meta:
         app_label = 'permission'
