@@ -1,16 +1,11 @@
 # coding=utf-8
-"""
-"""
-__author__ = 'Alisue <lambdalisue@hashnote.net>'
-from django.test import TestCase
-from permission.tests.utils import create_user
-from permission.tests.utils import create_article
-from permission.tests.models import Article
-from permission.tests.compatibility import MagicMock
-from permission.tests.compatibility import override_settings
-from permission.handlers import PermissionHandler
-from permission.handlers import LogicalPermissionHandler
-from permission.utils.handlers import PermissionHandlerRegistry
+from django.test import TestCase, override_settings
+from ..handlers import PermissionHandler
+from ..handlers import LogicalPermissionHandler
+from .utils import create_user, create_article
+from .models import Article
+from .compat import MagicMock
+
 
 @override_settings(
     PERMISSION_DEFAULT_PERMISSION_HANDLER=PermissionHandler
@@ -81,9 +76,9 @@ class PermissionPermissionHandlersTestCase(TestCase):
     def test_get_supported_permissions_with_includes(self):
         instance = self.handler(Article)
         instance.includes = [
-                'permission.add_article',
-                'permission.change_article',
-            ]
+            'permission.add_article',
+            'permission.change_article',
+        ]
         perms = instance.get_supported_permissions()
         self.assertEquals(perms, set([
             'permission.add_article',
@@ -93,24 +88,23 @@ class PermissionPermissionHandlersTestCase(TestCase):
     def test_get_supported_permissions_with_includes_change(self):
         instance = self.handler(Article)
         instance.includes = [
-                'permission.add_article',
-                'permission.change_article',
-            ]
+            'permission.add_article',
+            'permission.change_article',
+        ]
         instance.get_supported_permissions()
         instance.includes = [
-                'permission.change_article',
-            ]
+            'permission.change_article',
+        ]
         perms = instance.get_supported_permissions()
         self.assertEquals(perms, set([
             'permission.change_article',
         ]))
 
-
     def test_get_supported_permissions_with_excludes(self):
         instance = self.handler(Article)
         instance.excludes = [
-                'permission.add_article',
-            ]
+            'permission.add_article',
+        ]
         perms = instance.get_supported_permissions()
         self.assertEquals(perms, set([
             'permission.change_article',
@@ -120,8 +114,8 @@ class PermissionPermissionHandlersTestCase(TestCase):
     def test_get_supported_permissions_with_excludes_change(self):
         instance = self.handler(Article)
         instance.excludes = [
-                'permission.add_article',
-            ]
+            'permission.add_article',
+        ]
         instance.get_supported_permissions()
         instance.excludes = []
         perms = instance.get_supported_permissions()
@@ -141,9 +135,9 @@ class PermissionPermissionHandlersTestCase(TestCase):
     def test_get_supported_app_labels_with_includes(self):
         instance = self.handler(Article)
         instance.includes = [
-                'permission.add_article',
-                'permission.change_article',
-            ]
+            'permission.add_article',
+            'permission.change_article',
+        ]
         app_labels = instance.get_supported_app_labels()
         self.assertEquals(app_labels, set([
             'permission',
@@ -152,24 +146,23 @@ class PermissionPermissionHandlersTestCase(TestCase):
     def test_get_supported_app_labels_with_includes_change(self):
         instance = self.handler(Article)
         instance.includes = [
-                'permission.add_article',
-                'permission.change_article',
-            ]
+            'permission.add_article',
+            'permission.change_article',
+        ]
         instance.get_supported_app_labels()
         instance.includes = [
-                'permission.change_article',
-            ]
+            'permission.change_article',
+        ]
         app_labels = instance.get_supported_app_labels()
         self.assertEquals(app_labels, set([
             'permission',
         ]))
 
-
     def test_get_supported_app_labels_with_excludes(self):
         instance = self.handler(Article)
         instance.excludes = [
-                'permission.add_article',
-            ]
+            'permission.add_article',
+        ]
         app_labels = instance.get_supported_app_labels()
         self.assertEquals(app_labels, set([
             'permission',
@@ -178,8 +171,8 @@ class PermissionPermissionHandlersTestCase(TestCase):
     def test_get_supported_app_labels_with_excludes_change(self):
         instance = self.handler(Article)
         instance.excludes = [
-                'permission.add_article',
-            ]
+            'permission.add_article',
+        ]
         instance.get_supported_app_labels()
         instance.excludes = []
         app_labels = instance.get_supported_app_labels()
@@ -189,39 +182,45 @@ class PermissionPermissionHandlersTestCase(TestCase):
 
     def test_has_perm_add_wihtout_obj(self):
         instance = self.handler(Article)
-        self.assertRaises(NotImplementedError,
-                instance.has_perm,
-                self.user, self.perm1)
-        
+        self.assertRaises(
+            NotImplementedError,
+            instance.has_perm,
+            self.user, self.perm1)
+
     def test_has_perm_change_wihtout_obj(self):
         instance = self.handler(Article)
-        self.assertRaises(NotImplementedError,
-                instance.has_perm,
-                self.user, self.perm2)
+        self.assertRaises(
+            NotImplementedError,
+            instance.has_perm,
+            self.user, self.perm2)
 
     def test_has_perm_delete_wihtout_obj(self):
         instance = self.handler(Article)
-        self.assertRaises(NotImplementedError,
-                instance.has_perm,
-                self.user, self.perm3)
+        self.assertRaises(
+            NotImplementedError,
+            instance.has_perm,
+            self.user, self.perm3)
 
     def test_has_perm_add_wiht_obj(self):
         instance = self.handler(Article)
-        self.assertRaises(NotImplementedError,
-                instance.has_perm,
-                self.user, self.perm1, self.article)
+        self.assertRaises(
+            NotImplementedError,
+            instance.has_perm,
+            self.user, self.perm1, self.article)
 
     def test_has_perm_change_wiht_obj(self):
         instance = self.handler(Article)
-        self.assertRaises(NotImplementedError,
-                instance.has_perm,
-                self.user, self.perm2, self.article)
+        self.assertRaises(
+            NotImplementedError,
+            instance.has_perm,
+            self.user, self.perm2, self.article)
 
     def test_has_perm_delete_wiht_obj(self):
         instance = self.handler(Article)
-        self.assertRaises(NotImplementedError,
-                instance.has_perm,
-                self.user, self.perm3, self.article)
+        self.assertRaises(
+            NotImplementedError,
+            instance.has_perm,
+            self.user, self.perm3, self.article)
 
     def test_has_module_perms_success(self):
         instance = self.handler(Article)
@@ -237,11 +236,14 @@ class PermissionPermissionHandlersTestCase(TestCase):
         self.assertFalse(instance.has_module_perms(user, 'unknown'))
         self.assertFalse(user.has_perm.called)
 
+
 @override_settings(
-    PERMISSION_DEFAULT_PERMISSION_HANDLER=LogicalPermissionHandler
+    PERMISSION_DEFAULT_PERMISSION_HANDLER=LogicalPermissionHandler,
 )
 class PermissionLogicalPermissionHandlerTestCase(TestCase):
     def setUp(self):
+        # make sure all caches are removed
+        Article._permission_logics = set()
         self.handler = LogicalPermissionHandler
         self.user = create_user('john')
         self.perm1 = 'permission.add_article'
