@@ -1,11 +1,7 @@
 # coding=utf-8
-"""
-"""
-__author__ = 'Alisue <lambdalisue@hashnote.net>'
 from django.test import TestCase
-from permission.tests.utils import create_user
-from permission.tests.utils import create_article
-from permission.logics import PermissionLogic
+from ...logics import PermissionLogic
+from ..utils import create_user, create_article
 
 
 class PermissionLogicsPermissionLogicTestCase(TestCase):
